@@ -27,7 +27,7 @@ try:
 except ImportError:
     import unittest
 
-__version__ = '2.1.0'
+__version__ = '2.1.1'
 
 logger = getLogger(__name__)
 
@@ -173,7 +173,8 @@ class TestProcess(BufferingBase if fcntl else ThreadedBufferingBase):
             try:
                 data, _ = self.proc.communicate()
                 try:
-                    data = data.decode(self.ENCODING)
+                    if isinstance(data, bytes):
+                        data = data.decode(self.ENCODING)
                 except Exception as exc:
                     logger.exception("%s failed to decode %r: %r", self, data, exc)
                     raise
